@@ -4,6 +4,7 @@ from typing import Union, List, Optional, Dict, Any, NamedTuple
 
 from pyspark import keyword_only
 from pyspark.ml.param import Param
+from pyspark.sql import DataFrameReader
 from pyspark.sql.dataframe import DataFrame
 from pyspark.sql.functions import col, trim
 from pyspark.sql.types import DataType
@@ -15,6 +16,7 @@ from spark_pipeline_framework.progress_logger.progress_logger import ProgressLog
 from spark_pipeline_framework.transformers.framework_transformer.v1.framework_transformer import (
     FrameworkTransformer,
 )
+from spark_pipeline_framework.utilities.file_helpers import get_absolute_paths
 
 
 class ColumnSpec(NamedTuple):
@@ -50,6 +52,7 @@ class FrameworkFixedWidthLoader(FrameworkTransformer):
         view: str,
         filepath: Union[str, List[str], Path],
         columns: List[ColumnSpec],
+        has_header: bool = True,
         name: Optional[str] = None,
         parameters: Optional[Dict[str, Any]] = None,
         progress_logger: Optional[ProgressLogger] = None,
@@ -106,6 +109,9 @@ class FrameworkFixedWidthLoader(FrameworkTransformer):
         self.columns: Param[List[ColumnSpec]] = Param(self, "columns", "")
         self._setDefault(columns=None)
 
+        self.has_header: Param[bool] = Param(self, "has_header", "")
+        self._setDefault(has_header=True)
+
         if not filepath:
             raise ValueError("filepath is None or empty")
 
@@ -119,12 +125,18 @@ class FrameworkFixedWidthLoader(FrameworkTransformer):
         filepath: Union[str, List[str], Path] = self.getFilepath()
         columns: List[ColumnSpec] = self.getColumns()
         progress_logger: Optional[ProgressLogger] = self.getProgressLogger()
-        paths = self._get_absolute_paths(filepath=filepath)
+        paths = get_absolute_paths(filepath=filepath)
+        has_header = self.getHasHeader()
         progress_logger and progress_logger.write_to_log(
             f"Loading file for view {view}: {paths}"
         )
-        df_reader = df.sql_ctx.read.text(paths=paths)
-        df_reader = df_reader.select(
+
+        df_reader: DataFrameReader = df.sql_ctx.read
+        df_text = df_reader.text(paths=paths)
+        if has_header:
+            header = df_text.first()[0]
+            df_text = df_text.filter(~col("value").contains(header))  # type:ignore
+        df_text = df_text.select(
             *[
                 trim(col("value").substr(column.start_pos, column.length))
                 .cast(column.data_type)
@@ -132,44 +144,13 @@ class FrameworkFixedWidthLoader(FrameworkTransformer):
                 for column in columns
             ]
         )
-        df_reader.createOrReplaceTempView(view)
+        df_text.createOrReplaceTempView(view)
 
         progress_logger and progress_logger.write_to_log(
             f"Finished Loading file for View[{view}]: {paths}"
         )
         return df
 
-    def _get_absolute_paths(self, filepath: Union[str, List[str], Path]) -> List[str]:
-        """
-        Abstracts handling of paths so we can use paths on both k8s in AWS as well as local
-
-        :param filepath: the path or paths to format appropriately
-        :return: a list of paths optimized for local or k8s usages
-        """
-        if not filepath:
-            raise ValueError(f"filepath is empty: {filepath}")
-
-        if isinstance(filepath, str):
-            if filepath.__contains__(":"):
-                return [filepath]
-            else:
-                data_dir = Path(__file__).parent.parent.joinpath("./")
-                return [f"file://{data_dir.joinpath(filepath)}"]
-        elif isinstance(filepath, Path):
-            data_dir = Path(__file__).parent.parent.joinpath("./")
-            return [f"file://{data_dir.joinpath(filepath)}"]
-        elif isinstance(filepath, (list, tuple)):
-            data_dir = Path(__file__).parent.parent.joinpath("./")
-            absolute_paths = []
-            for path in filepath:
-                if ":" in path:
-                    absolute_paths.append(path)
-                else:
-                    absolute_paths.append(f"file://{data_dir.joinpath(path)}")
-            return absolute_paths
-        else:
-            raise TypeError(f"Unknown type '{type(filepath)}' for filepath {filepath}")
-
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getView(self) -> str:
         return self.getOrDefault(self.view)
@@ -181,3 +162,7 @@ class FrameworkFixedWidthLoader(FrameworkTransformer):
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getColumns(self) -> List[ColumnSpec]:
         return self.getOrDefault(self.columns)
+
+    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
+    def getHasHeader(self) -> bool:
+        return self.getOrDefault(self.has_header)
